@@ -2,22 +2,17 @@
 
 set -e
 
-# if you compile first time you must change variable "lazpath" and "lcl"
-# after it execute this script with parameter "all" at doublecmd dir 
-# "./build.sh all" it build doublecmd
-#                                                 by Attid
-
-
 # You can execute this script with different parameters:
-# components - compiling components needed for DC
-# plugins - compiling all DC plugins
-# all - compiling components, plugins and DC
-# default - compiling DC only (using by default)
+# components - compiling components needed for doublecmd
+# doublecmd - compiling doublecmd only (release mode)
+# plugins - compiling all doublecmd plugins
+# debug - compiling components, plugins and doublecmd (debug mode)
+# release - compile in release mode (using by default)
 
 # path to lazbuild
 export lazbuild=$(which lazbuild)
 
-# Set up widgetset: gtk or gtk2 or qt
+# Set up widgetset: gtk2 or qt or qt5 or cocoa
 # Set up processor architecture: i386 or x86_64
 if [ $2 ]
   then export lcl=$2
@@ -30,47 +25,46 @@ elif [ $CPU_TARGET ]
   then export DC_ARCH=$(echo "--cpu=$CPU_TARGET")
 fi
 
-build_default()
+build_doublecmd()
 {
-  $lazbuild src/doublecmd.lpi $DC_ARCH
-  
-  strip doublecmd
-}
-
-build_beta()
-{
-  components/build.sh
-  plugins/build.sh
-  
   # Build Double Commander
-  $lazbuild src/doublecmd.lpi --bm=beta $DC_ARCH
-  
+  $lazbuild src/doublecmd.lpi --bm=release $DC_ARCH
+
   # Build Dwarf LineInfo Extractor
   $lazbuild tools/extractdwrflnfo.lpi
-  
+
   # Extract debug line info
   chmod a+x tools/extractdwrflnfo
   if [ -f doublecmd.dSYM/Contents/Resources/DWARF/doublecmd ]; then
     mv -f doublecmd.dSYM/Contents/Resources/DWARF/doublecmd $(pwd)/doublecmd.dbg
   fi
   tools/extractdwrflnfo doublecmd.dbg
-  
+
   # Strip debug info
   strip doublecmd
 }
 
-build_all()
+build_release()
 {
   components/build.sh
   plugins/build.sh
-  build_default
+  build_doublecmd
+}
+
+build_debug()
+{
+  components/build.sh
+  plugins/build.sh
+
+  # Build Double Commander
+  $lazbuild src/doublecmd.lpi --bm=debug $DC_ARCH
 }
 
 
 case $1 in
   components)  components/build.sh;;
+   doublecmd)  build_doublecmd;;
      plugins)  plugins/build.sh;;
-        beta)  build_beta;;
-         all)  build_all;;
-           *)  build_default;;
+       debug)  build_debug;;
+           *)  build_release;;
 esac
