@@ -1,3 +1,6 @@
+#ifndef _WDX_H
+#define _WDX_H
+
 #include "common.h"
 
 // Contents of file contplug.h version 2.0
@@ -80,6 +83,10 @@ typedef struct {
 	WORD wSecond;
 } ttimeformat,*ptimeformat;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int DCPCALL ContentGetDetectString(char* DetectString,int maxlen);
 int DCPCALL ContentGetSupportedField(int FieldIndex,char* FieldName,char* Units,int maxlen);
 int DCPCALL ContentGetValue(char* FileName,int FieldIndex,int UnitIndex,void* FieldValue,int maxlen,int flags);
@@ -97,4 +104,10 @@ int DCPCALL ContentSetValueW(WCHAR* FileName,int FieldIndex,int UnitIndex,int Fi
 int DCPCALL ContentEditValue(HWND ParentWin,int FieldIndex,int UnitIndex,int FieldType,
                 void* FieldValue,int maxlen,int flags,char* langidentifier);
 void DCPCALL ContentSendStateInformation(int state,char* path);
-void DCPCALL ContentSendStateInformationW(int state,WCHAR* path);
\ No newline at end of file
+void DCPCALL ContentSendStateInformationW(int state,WCHAR* path);
+
+#ifdef __cplusplus
+}
+#endif
+
+#endif // _WDX_H
